@@ -6,11 +6,26 @@ use syn::{ImplItemMethod, ItemFn};
 /// Async Struct
 pub struct Async;
 
+#[derive(Debug, PartialEq, Clone, Copy)]
+/// Function visibility.
+pub enum Visibility {
+    /// Public
+    Public,
+    /// Crate
+    Crate,
+    /// Restricted
+    Restricted,
+    /// Inherited
+    Inherited,
+}
+
 #[derive(Debug, PartialEq, Clone)]
 /// Function Struct
 pub struct Function {
     /// Attributes field.
     pub attributes: Attributes,
+    /// Visibility field.
+    pub visibility: Visibility,
     /// Asyncness field.
     pub asyncness: Option<Async>,
     /// Identifier field.
@@ -21,6 +36,17 @@ pub struct Function {
     pub output: Option<Type>,
 }
 
+impl From<syn::Visibility> for Visibility {
+    fn from(visibility: syn::Visibility) -> Self {
+        match visibility {
+            syn::Visibility::Public(_) => Self::Public,
+            syn::Visibility::Crate(_) => Self::Crate,
+            syn::Visibility::Restricted(_) => Self::Restricted,
+            syn::Visibility::Inherited => Self::Inherited,
+        }
+    }
+}
+
 macro_rules! impl_function {
     ($T:ident) => {
         impl From<$T> for Function {
@@ -51,6 +77,7 @@ macro_rules! impl_function {
                             .map(|x| x.parse_meta().expect("Failed to parse Meta").into())
                             .collect(),
                     },
+                    visibility: Visibility::from(item_fn.vis),
                     asyncness: match asyncness {
                         Some(_x) => Some(Async),
                         None => None,
@@ -70,7 +97,9 @@ impl_function!(ImplItemMethod);
 #[cfg(test)]
 mod test {
     use super::{Async, Function, ImplItemMethod, ItemFn, Type};
-    use crate::ir::{Attribute, Attributes, Identifier, Literal, Parameter, Reference, ReferenceKind};
+    use crate::ir::{
+        Attribute, Attributes, Identifier, Literal, Parameter, Reference, ReferenceKind, Visibility,
+    };
     use quote::quote;
     use syn::parse_quote::parse;
 
@@ -80,6 +109,7 @@ mod test {
             Function::from(parse::<ItemFn>(quote! {fn test() {}})),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![],
@@ -94,6 +124,7 @@ mod test {
             Function::from(parse::<ImplItemMethod>(quote! {fn test() {}})),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![],
@@ -108,6 +139,7 @@ mod test {
             Function::from(parse::<ItemFn>(quote! {fn test(a: String, b: String) {}})),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![
@@ -131,6 +163,7 @@ mod test {
             Function::from(parse::<ItemFn>(quote! {fn test() -> String {}})),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![],
@@ -147,6 +180,7 @@ mod test {
             )),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![
@@ -156,32 +190,26 @@ mod test {
                     },
                     Parameter {
                         identifier: Identifier::new("b"),
-                        type_: Type::Reference(
-                            Reference {
-                                kind: ReferenceKind::Borrow,
-                                is_constant: true,
-                                type_: Box::new(Type::Compound(Identifier::new("String")))
-                            }
-                        )
+                        type_: Type::Reference(Reference {
+                            kind: ReferenceKind::Borrow,
+                            is_constant: true,
+                            type_: Box::new(Type::Compound(Identifier::new("String")))
+                        })
                     },
                     Parameter {
                         identifier: Identifier::new("c"),
-                        type_: Type::Reference(
-                            Reference {
-                                kind: ReferenceKind::Borrow,
-                                is_constant: false,
-                                type_: Box::new(Type::Compound(Identifier::new("String")))
-                            }
-                        )
+                        type_: Type::Reference(Reference {
+                            kind: ReferenceKind::Borrow,
+                            is_constant: false,
+                            type_: Box::new(Type::Compound(Identifier::new("String")))
+                        })
                     },
                 ],
-                output: Some(Type::Reference(
-                    Reference {
-                        kind: ReferenceKind::Borrow,
-                        is_constant: true,
-                        type_: Box::new(Type::Compound(Identifier::new("String")))
-                    }
-                ))
+                output: Some(Type::Reference(Reference {
+                    kind: ReferenceKind::Borrow,
+                    is_constant: true,
+                    type_: Box::new(Type::Compound(Identifier::new("String")))
+                }))
             }
         );
     }
@@ -205,6 +233,7 @@ mod test {
                         }
                     )]
                 },
+                visibility: Visibility::Inherited,
                 asyncness: None,
                 identifier: Identifier::new("test"),
                 inputs: vec![],
@@ -219,6 +248,7 @@ mod test {
             Function::from(parse::<ItemFn>(quote! {async fn test() {}})),
             Function {
                 attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Inherited,
                 asyncness: Some(Async),
                 identifier: Identifier::new("test"),
                 inputs: vec![],
@@ -246,6 +276,7 @@ mod test {
                         }
                     )]
                 },
+                visibility: Visibility::Inherited,
                 asyncness: Some(Async),
                 identifier: Identifier::new("test"),
                 inputs: vec![
@@ -255,32 +286,41 @@ mod test {
                     },
                     Parameter {
                         identifier: Identifier::new("b"),
-                        type_: Type::Reference(
-                            Reference {
-                                kind: ReferenceKind::Borrow,
-                                is_constant: true,
-                                type_: Box::new(Type::Compound(Identifier::new("String")))
-                            }
-                        )
+                        type_: Type::Reference(Reference {
+                            kind: ReferenceKind::Borrow,
+                            is_constant: true,
+                            type_: Box::new(Type::Compound(Identifier::new("String")))
+                        })
                     },
                     Parameter {
                         identifier: Identifier::new("c"),
-                        type_: Type::Reference(
-                            Reference {
-                                kind: ReferenceKind::Borrow,
-                                is_constant: false,
-                                type_: Box::new(Type::Compound(Identifier::new("String")))
-                            }
-                        )
+                        type_: Type::Reference(Reference {
+                            kind: ReferenceKind::Borrow,
+                            is_constant: false,
+                            type_: Box::new(Type::Compound(Identifier::new("String")))
+                        })
                     },
                 ],
-                output: Some(Type::Reference(
-                    Reference {
-                        kind: ReferenceKind::Borrow,
-                        is_constant: true,
-                        type_: Box::new(Type::Compound(Identifier::new("String")))
-                    }
-                ))
+                output: Some(Type::Reference(Reference {
+                    kind: ReferenceKind::Borrow,
+                    is_constant: true,
+                    type_: Box::new(Type::Compound(Identifier::new("String")))
+                }))
+            }
+        );
+    }
+
+    #[test]
+    fn function_pub() {
+        assert_eq!(
+            Function::from(parse::<ImplItemMethod>(quote! {pub fn test() {}})),
+            Function {
+                attributes: Attributes { attributes: vec![] },
+                visibility: Visibility::Public,
+                asyncness: None,
+                identifier: Identifier::new("test"),
+                inputs: vec![],
+                output: None
             }
         );
     }
