@@ -10,8 +10,6 @@
 #![warn(unused_qualifications)]
 
 mod prelude;
-mod proc_macro;
-
+pub mod proc_macro;
 pub mod ir;
-
-pub use proc_macro::ligen;
\ No newline at end of file
+pub mod utils;
\ No newline at end of file
